==> jc-1.4.0.tar.gz: javax/xml/transform/TransformerFactoryConfigurationError.h <==
// public class javax.xml.transform.TransformerFactoryConfigurationError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 1e13266a59223879 javax_xml_transform_TransformerFactoryConfigurationError

// header file dependencies
// @dep_header java_lang_Error

#include "java/lang/Error.h"

#ifndef _JC_javax_xml_transform_TransformerFactoryConfigurationError_H_
#define _JC_javax_xml_transform_TransformerFactoryConfigurationError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$sub_refs	_jc_javax_xml_transform_TransformerFactoryConfigurationError$sub_refs;
typedef struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$sub_nonrefs	_jc_javax_xml_transform_TransformerFactoryConfigurationError$sub_nonrefs;
typedef struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$refs	_jc_javax_xml_transform_TransformerFactoryConfigurationError$refs;
typedef struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$nonrefs	_jc_javax_xml_transform_TransformerFactoryConfigurationError$nonrefs;
typedef struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$object	_jc_javax_xml_transform_TransformerFactoryConfigurationError$object;

typedef const struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$vmethods	_jc_javax_xml_transform_TransformerFactoryConfigurationError$vmethods;
typedef const struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$vtable	_jc_javax_xml_transform_TransformerFactoryConfigurationError$vtable;
typedef const struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$vtype	_jc_javax_xml_transform_TransformerFactoryConfigurationError$vtype;

// Constructors
extern void _jc_javax_xml_transform_TransformerFactoryConfigurationError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$object *);
extern void _jc_javax_xml_transform_TransformerFactoryConfigurationError$method$_init$34e2c2e16bd56612(_jc_env *, struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$object *, struct _jc_java_lang_Exception$object *);
extern void _jc_javax_xml_transform_TransformerFactoryConfigurationError$method$_init$82e384f63a3614a6(_jc_env *, struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$object *, struct _jc_java_lang_Exception$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_xml_transform_TransformerFactoryConfigurationError$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_Exception$object *_jc_javax_xml_transform_TransformerFactoryConfigurationError$method$getException$bcbfe86f697cf912(_jc_env *, struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$object *);
extern struct _jc_java_lang_String$object *_jc_javax_xml_transform_TransformerFactoryConfigurationError$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_xml_transform_TransformerFactoryConfigurationError$method_info$getException$bcbfe86f697cf912;
extern _jc_method _jc_javax_xml_transform_TransformerFactoryConfigurationError$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$vmethods {
	struct _jc_java_lang_Exception$object	*(*getException$bcbfe86f697cf912)(_jc_env *, struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$object *);
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$object *);
};

// Vtable
struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_javax_xml_transform_TransformerFactoryConfigurationError$vmethods	javax_xml_transform_TransformerFactoryConfigurationError;
};

// Vtype
struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$vtype {
	_jc_type			type;
	_jc_javax_xml_transform_TransformerFactoryConfigurationError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$sub_refs {
	struct _jc_java_lang_Exception$object	*exception;
};

// Reference instance fields (object)
struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$refs {
    _jc_javax_xml_transform_TransformerFactoryConfigurationError$sub_refs	javax_xml_transform_TransformerFactoryConfigurationError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_javax_xml_transform_TransformerFactoryConfigurationError$sub_nonrefs	javax_xml_transform_TransformerFactoryConfigurationError;
};

// Object instance structure
struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$object {
	_jc_javax_xml_transform_TransformerFactoryConfigurationError$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_transform_TransformerFactoryConfigurationError$vtype	*vtype;
	_jc_javax_xml_transform_TransformerFactoryConfigurationError$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_transform_TransformerFactoryConfigurationError$vtype _jc_javax_xml_transform_TransformerFactoryConfigurationError$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_transform_TransformerFactoryConfigurationError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_transform_TransformerFactoryConfigurationError$class_object;

#endif	/* _JC_javax_xml_transform_TransformerFactoryConfigurationError_H_ */

==> jc-1.4.6.tar.gz: javax/xml/transform/TransformerFactoryConfigurationError.h <==
// public class javax.xml.transform.TransformerFactoryConfigurationError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 1e13266a59223879 javax_xml_transform_TransformerFactoryConfigurationError

// header file dependencies
// @dep_header java_lang_Error

#include "java/lang/Error.h"

#ifndef _JC_javax_xml_transform_TransformerFactoryConfigurationError_H_
#define _JC_javax_xml_transform_TransformerFactoryConfigurationError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$sub_refs	_jc_javax_xml_transform_TransformerFactoryConfigurationError$sub_refs;
typedef struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$sub_nonrefs	_jc_javax_xml_transform_TransformerFactoryConfigurationError$sub_nonrefs;
typedef struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$refs	_jc_javax_xml_transform_TransformerFactoryConfigurationError$refs;
typedef struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$nonrefs	_jc_javax_xml_transform_TransformerFactoryConfigurationError$nonrefs;
typedef struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$object	_jc_javax_xml_transform_TransformerFactoryConfigurationError$object;

typedef const struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$vmethods	_jc_javax_xml_transform_TransformerFactoryConfigurationError$vmethods;
typedef const struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$vtable	_jc_javax_xml_transform_TransformerFactoryConfigurationError$vtable;
typedef const struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$vtype	_jc_javax_xml_transform_TransformerFactoryConfigurationError$vtype;

// Constructors
extern void _jc_javax_xml_transform_TransformerFactoryConfigurationError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_transform_TransformerFactoryConfigurationError$method$_init$34e2c2e16bd56612(_jc_env *, struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$object *, struct _jc_java_lang_Exception$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_transform_TransformerFactoryConfigurationError$method$_init$82e384f63a3614a6(_jc_env *, struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$object *, struct _jc_java_lang_Exception$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_transform_TransformerFactoryConfigurationError$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Exception$object *_jc_javax_xml_transform_TransformerFactoryConfigurationError$method$getException$bcbfe86f697cf912(_jc_env *, struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_xml_transform_TransformerFactoryConfigurationError$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_xml_transform_TransformerFactoryConfigurationError$method_info$getException$bcbfe86f697cf912;
extern _jc_method _jc_javax_xml_transform_TransformerFactoryConfigurationError$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$vmethods {
	struct _jc_java_lang_Exception$object	*(*getException$bcbfe86f697cf912)(_jc_env *, struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_javax_xml_transform_TransformerFactoryConfigurationError$vmethods	javax_xml_transform_TransformerFactoryConfigurationError;
};

// Vtype
struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$vtype {
	_jc_type			type;
	_jc_javax_xml_transform_TransformerFactoryConfigurationError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$sub_refs {
	struct _jc_java_lang_Exception$object	*exception;
};

// Reference instance fields (object)
struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$refs {
    _jc_javax_xml_transform_TransformerFactoryConfigurationError$sub_refs	javax_xml_transform_TransformerFactoryConfigurationError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_javax_xml_transform_TransformerFactoryConfigurationError$sub_nonrefs	javax_xml_transform_TransformerFactoryConfigurationError;
};

// Object instance structure
struct _jc_javax_xml_transform_TransformerFactoryConfigurationError$object {
	_jc_javax_xml_transform_TransformerFactoryConfigurationError$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_transform_TransformerFactoryConfigurationError$vtype	*vtype;
	_jc_javax_xml_transform_TransformerFactoryConfigurationError$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_transform_TransformerFactoryConfigurationError$vtype _jc_javax_xml_transform_TransformerFactoryConfigurationError$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_transform_TransformerFactoryConfigurationError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_transform_TransformerFactoryConfigurationError$class_object;

#endif	/* _JC_javax_xml_transform_TransformerFactoryConfigurationError_H_ */
